@@ -1,14 +1,14 @@
-from typing import Any,  Tuple, Optional, List, Dict, Union, Type, Generic, TypeVar
-from pydantic import BaseModel, Extra, ValidationError, validator, create_model, root_validator
+from typing import Any, Tuple, Optional, List,  Union, Type, TypeVar, Iterator
+from pydantic import BaseModel, Extra,  validator, create_model, root_validator, ValidationError
 from pydantic.class_validators import root_validator
 
 from ._class_recorder import get_class, KINDS
-from ._core_model_var import StaticVar
+from ._core_model_var import StaticVar, NodeVar
 
 from ._core_pydantic import _default_walk_set
 from enum import Enum 
 import yaml
-from ..io import ioconfig, load_yaml, load_config
+from ..io import ioconfig, load_config, parse_file_name
 import logging 
 import weakref
 
@@ -25,17 +25,10 @@ CONFIG_MODE_DEFAULT = CONFIG_MODE.DEFAULT
 
 ObjVar = TypeVar('ObjVar')
 
-
-class IOConfig(BaseModel):
-    """ model for cfgfile definition """    
-    cfgfile: str = ""
-    class Config:
-        extra = Extra.allow
     
 class BaseConfig(BaseModel):
     kind: KINDS = ""
     type: str = ""
-    version: str = "" # version of the configuration file
 
     
     class Config: # this is the Config of BaseModel
@@ -53,15 +46,9 @@ class BaseConfig(BaseModel):
         # This is important to pop the cfgfile, so this will not be executed every time there is 
         # an attribute assignment 
         cfgfile = values.pop('cfgfile', None) 
-        cfgfile_path = values.pop('cfgfile_path', None)
 
         if cfgfile:
-            print("I sshould be called ones")
             cfg = load_config(cfgfile)
-            if cfgfile_path:
-                if isinstance(cfgfile_path, list):
-                    cfgfile_path = tuple(cfgfile_path)
-                cfg = path_walk_item(cfg, path(cfgfile_path))
             for k, v in cfg.items():
                 values.setdefault(k,v)
         return values
@@ -90,56 +77,6 @@ class BaseConfig(BaseModel):
     def validate_type(cls, type_):
         return type_
     
-    # @classmethod
-    # def validate(cls, v, field):
-    #     if field.sub_fields:
-    #         if len(field.sub_fields)!=1:
-    #             raise ValidationError(['to many field GenDevice require and accept only one argument'], cls)
-        
-
-    #         val_f = field.sub_fields[0]
-    #         errors = []
-        
-    #         valid_value, error = val_f.validate(v, {}, loc='value')
-
-    #         if error:
-    #             errors.append(error)
-    #         if errors:
-    #             raise ValidationError(errors, cls)
-    #     else:
-    #         valid_value = v
-        
-        
-    #     if isinstance(valid_value, dict):
-    #         haskind, hastype = False, False
-    #         if 'kind' in valid_value:
-    #             valid_value['kind'] = cls.validate_kind( valid_value['kind'])
-    #             haskind = True
-    #         if 'type' in valid_value:
-    #             hastype = True
-    #             valid_value['type'] = cls.validate_type( valid_value['type'])
-
-    #         if isinstance( field.default, BaseConfig ):
-    #             c_kind = valid_value.get('kind', field.default.kind)
-    #             c_type = valid_value.get('kind', field.default.type)
-
-
-    #             if (c_kind!= field.default.kind) or\
-    #                (c_type!= field.default.type):
-    #                     Obj = get_class(c_kind, c_type)
-    #                     cls = Obj.Config
-
-
-    #     return cls.parse_obj(valid_value)
-        #return valid_value   
-
-
-    # @classmethod
-    # def __get_validators__(cls):
-    #     yield cls.validate
-
-    
-
 
     @classmethod
     def from_cfgfile(cls, cfgfile, path: str = ''):
@@ -158,10 +95,7 @@ class BaseConfig(BaseModel):
     
 
 class ChildrenCapabilityConfig(BaseModel): 
-    auto_build: bool = AUTO_BUILD_DEFAULT
-    
-    
-    
+    auto_build: bool = AUTO_BUILD_DEFAULT 
 
     @root_validator(pre=False)
     def _root_post_validator(cls, values):
@@ -169,10 +103,16 @@ class ChildrenCapabilityConfig(BaseModel):
 
         This will only be used if extra="allow"
         """
+        errors = []
         for k,v in values.items():
             if k in cls.__fields__: # field exist in the class and will be treated independently 
                 continue
-            values[k] = cls.validate_extra(k, v, values)
+            try:
+                values[k] = cls.validate_extra(k, v, values)
+            except ValueError as e:
+                errors.append(e)
+        if errors:
+            raise ValueError( "\n\n  ".join(str(e) for e in errors))
         return values
     
     @classmethod
@@ -180,6 +120,11 @@ class ChildrenCapabilityConfig(BaseModel):
         if isinstance(extra, dict) and "kind" in extra and "type" in extra:
             ObjClass = get_class(extra["kind"], extra["type"])
             return ObjClass.Config.parse_obj(extra)
+        
+        if getattr( cls.Config, "extra_obj_only", False):
+            if isinstance( extra, _BaseObject.Config):
+                return extra
+            raise ValueError(f"""Extra {name!r} of type {type(extra)} not allowed""") 
         return extra
 
 
@@ -332,9 +277,6 @@ class BaseData(BaseModel):
     # place holder for Data class 
     key: StaticVar[str] = ""
 
-class ChildError(ValueError):
-    """ Error raise when a parent try to reach a child object (interface, node, rpc, ...) and cannot find it"""
-    pass
 
 def load_yaml_config(yaml_payload: str, path: Optional[Union[str, tuple]] = None) -> Tuple[Type,BaseConfig]:
     """ Load a yaml configuration and pare it in the right configuration object 
@@ -635,7 +577,11 @@ class _BaseObject:
             path (None, str, False)"" the hierarchique path where to find the config data inside the file 
                     for instance 'a.b.c' will loock at cfg['a']['b']['c'] from the loaded config file 
                     If "" the config file define the device configuration from its root 
-                    If None the first item of the config file is taken 
+                    If None the first item of the config file is taken. 
+                    Note that the path can be defined directly inside the cfgfile file name
+                    in the form ``path/to/myconfig.yml[a.b.c]`` see :func:`load_config`
+
+                                
             prefix (str, optional): add a prefix to the path name to build the device key. 
                     It is used only if key is None otherwhise ignored
         """
@@ -645,9 +591,16 @@ class _BaseObject:
         
         allconf.update(**kwargs)
                
-        if key is None and isinstance(path, str): 
-            _, name = ksplit(path)           
-            key = kjoin(prefix, name)
+        if key is None:
+            if path and isinstance(path, str): 
+                _, name = ksplit(path)           
+                key = kjoin(prefix, name)
+            else:
+                # try with the path defined in file name 
+                _, p = parse_file_name(cfgfile)
+                if p:
+                    key = p[-1]
+                
 
         config = cls.Config.from_cfgfile( cfgfile, path )
         return cls(key = key, config=config, **kwargs)
@@ -704,7 +657,8 @@ class _BaseObject:
 class ChildrenCapability:
     _all_cashed = False
     _auto_build_object = AUTO_BUILD_DEFAULT
-    def find(self, cls: Type[_BaseObject], depth: int = 0):
+
+    def find(self, cls: Type[_BaseObject], depth: int = 0) -> Iterator:
         """ iterator on  children matching the given  class 
         
         ...note::
@@ -732,7 +686,7 @@ class ChildrenCapability:
             
     
             
-    def build_all(self, depth:int =0):
+    def build_all(self, depth:int =0) -> None:
         """ Build all possible children objects 
         
         Every single children will be built inside the object and will be cashed inside the obj.__dict__
@@ -753,7 +707,7 @@ class ChildrenCapability:
                     if depth!=0 and isinstance(obj, ChildrenCapability):
                             obj.build_all(depth-1)
 
-    def clear_all(self):
+    def clear_all(self) -> None:
         """ Remove all instances of children object they a re rebuilt on demand """
         for k,v in list(self.__dict__.items()):
             if isinstance( v, _BaseObject ):
@@ -771,14 +725,14 @@ class ChildrenCapability:
             else:
                 raise e
 
-    def children(self, cls: Optional[_BaseObject] = _BaseObject):
+    def children(self, cls: Optional[_BaseObject] = _BaseObject) -> Iterator:
         """ iter on children attribute name 
 
         Args:
             cls: the class which shall match the object. By default it will be all pydevmgr objects
             (:class:`pydevmgr_core._BaseObject`)
 
-        Exemple::
+        Example::
                 
             >>> l = [getattr(manager, name) for name in  manager.children( BaseDevice )]
             # is equivalent to 
@@ -794,14 +748,24 @@ class ChildrenCapability:
                 yield name  
     
     
-    def create_data_class( self, children,  Base = None ):
-               
+    def create_data_class( self, children: Iterator[str],  Base = None ) -> Type[BaseData]:
+        """ Create a new data class for the object according to a child name list 
+
+        This is a quick and durty way to create a data class dynamicaly. To be used mostly 
+        in a manager or device with dynamic children. 
+        Manager, Device, Interface child will be build from their defined Data class 
+        Nodes will be of ``Any`` type and filled with ``None`` as default. 
+        
+        """       
         data_obj = {}
         for name in children:
             obj = getattr(self, name)
-            data_obj[name] = (obj.Data, obj.Data())
-         
-        return create_model( "Data_Of_"+self.key, __base__=self.Data, **data_obj  )
+            if hasattr( obj, "get"):
+                data_obj[name] = (NodeVar[Any], None)
+            else:
+                data_obj[name] = (obj.Data, obj.Data())
+        Base  = self.Data if Base is None else Base 
+        return create_model( "Data_Of_"+self.key, __base__= Base, **data_obj  )
 
 
 
@@ -830,77 +794,3 @@ class _BaseObjDictProperty:
     pass
 
 
-
-class ObjectIterator:
-    _iterator = None
-    def __init__(self, obj, constructor, names):
-        self._obj = obj
-        self._constructor = constructor
-        self._names = names 
-    
-    def __iter__(self):
-        self._iterator = iter(self._names)
-        return self
-    
-    def __next__(self):
-        name = next(self._iterator)
-        try:
-            return object.__getattribute__(self._obj, name)
-        except AttributeError:
-            return self._constructor(name)
-        
-    def __getitem__(self, name):
-        
-        try:
-            return object.__getattribute__(self._obj, name)
-        except AttributeError:
-            return self._constructor(name)
-    
-    def __call__(self) -> List:
-        return list(self)
-    
-    def names(self) -> List:
-        return list(self._names)
-       
-       
-class _Old_ObjectIterator_To_delete:
-    _iterator = None
-    def __init__(self, map: dict, classes: Union[Type,Tuple[Type]]):
-        self._map = map
-        self._classes = classes 
-    
-    def __iter__(self):
-        self._iterator = iter(self._map.items())
-        return self
-    
-    def __next__(self):
-        k,v = next(self._iterator)
-        if isinstance(v, self._classes):
-            return v
-        return self.__next__()
-    
-    def __getitem__(self, item):
-        v = self._map[item]
-        if isinstance(v, self._classes):
-            return v 
-        raise KeyError(item)
-    
-    def __call__(self) -> List:
-        return list(self)
-    
-    def names(self) -> List:
-        return [k for k,v in self._map.items() if isinstance(v, self._classes)]
-       
-def _collect_config_properties(cls, prop_kind):
-    for sub in cls.__mro__:
-        for k,v in sub.__dict__.items():
-            if isinstance(v, (_BaseProperty)):
-                if v._config.kind is prop_kind:
-                    yield k, v._config
-
-
-
-
-
-                       
-        
